"""
This type stub file was generated by pyright.
"""

from models.admin import ACL, Address, Job, Organization, Permission, ProductType, ReportItemType, Role, Template, User
from models.base import TaranisBaseModel
from models.dashboard import Dashboard, TrendingCluster
from models.types import WORKER_CATEGORY, WORKER_TYPES, TLPLevel

"""
This type stub file was generated by pyright.
"""
__all__ = [
    "ACL",
    "Job",
    "Address",
    "Organization",
    "Role",
    "User",
    "Permission",
    "Dashboard",
    "Template",
    "ReportItemType",
    "ProductType",
    "TrendingCluster",
    "WORKER_TYPES",
    "WORKER_CATEGORY",
    "TaranisBaseModel",
    "TLPLevel",
]



"""
This type stub file was generated by pyright.
"""

from datetime import datetime
from typing import Literal

from pydantic import BaseModel

from models.assess import StoryTag
from models.base import TaranisBaseModel

"""
This type stub file was generated by pyright.
"""

DashboardHealthState = Literal["up", "down", "n/a"]

class DashboardHealthServices(BaseModel):
    database: DashboardHealthState
    broker: DashboardHealthState
    workers: DashboardHealthState

class DashboardHealth(BaseModel):
    healthy: bool
    services: DashboardHealthServices

class Dashboard(TaranisBaseModel):
    _core_endpoint = ...
    _model_name = ...
    _pretty_name = ...
    _cache_timeout = ...
    total_news_items: int = ...
    total_story_items: int = ...
    total_products: int = ...
    report_items_completed: int = ...
    report_items_in_progress: int = ...
    latest_collected: datetime | None = ...
    schedule_length: int | None = ...
    conflict_count: int | None = ...
    health_status: DashboardHealth | None = ...
    worker_status: dict[str, dict[str, int]] | None = ...

class TrendingCluster(TaranisBaseModel):
    _core_endpoint = ...
    _model_name = ...
    _pretty_name = ...
    name: str
    tags: list[StoryTag] = ...
    size: int | None = ...

class Cluster(TaranisBaseModel):
    _core_endpoint = ...
    _model_name = ...
    _pretty_name = ...
    name: str
    size: int | None = ...



from datetime import datetime, timezone
from typing import Any, Literal

from pydantic import AnyUrl, Field, PastDatetime, SecretStr, field_serializer, field_validator, model_validator

from models.base import TaranisBaseModel
from models.types import (
    BOT_TYPES,
    COLLECTOR_TYPES,
    CONNECTOR_TYPES,
    PRESENTER_TYPES,
    PUBLISHER_TYPES,
    WORKER_CATEGORY,
    WORKER_TYPES,
    AttributeType,
    ItemType,
    TLPLevel,
)


def _utcnow() -> datetime:
    return datetime.now(timezone.utc).replace(tzinfo=None)


def _normalize_datetime(value: datetime | None) -> datetime | None:
    if value is None or value.tzinfo is None or value.utcoffset() is None:
        return value
    return value.astimezone(timezone.utc).replace(tzinfo=None)


class ExportStoriesQuery(TaranisBaseModel):
    timefrom: PastDatetime | None = None
    timeto: PastDatetime | None = None
    metadata: bool = False

    @field_validator("timefrom", "timeto", mode="before")
    @classmethod
    def empty_string_to_none(cls, value):
        if value == "":
            return None
        return value

    @field_validator("timefrom", "timeto", mode="after")
    @classmethod
    def normalize_utc_naive(cls, value: PastDatetime | None) -> datetime | None:
        return _normalize_datetime(value)

    @model_validator(mode="after")
    def set_timeto_default(self):
        if self.timefrom and (self.timeto is None or self.timeto < self.timefrom):
            self.timeto = _utcnow()
        return self


class Job(TaranisBaseModel):
    _core_endpoint = "/config/schedule"
    _model_name = "job"
    _pretty_name = "Scheduler"

    id: str | None = None
    name: str
    trigger: str | None = None
    kwargs: str | None = None
    next_run_time: str | None = None


class TaskResult(TaranisBaseModel):
    _core_endpoint = "/config/task-results"
    _model_name = "task_result"
    _pretty_name = "Task Result"

    id: str | None = None
    result: Any | None = None
    status: str | None = None
    last_change: datetime | None = None
    last_success: datetime | None = None

    def __eq__(self, other: object) -> bool:
        return self.status == (other.status if isinstance(other, TaskResult) else other)

    def __lt__(self, other: object) -> bool:
        other_status = other.status if isinstance(other, TaskResult) else other

        if self.status is None:
            return other_status is not None
        return False if other_status is None else str(self.status) < str(other_status)


class Address(TaranisBaseModel):
    city: str = ""
    country: str = ""
    street: str = ""
    zip: str = ""


class Organization(TaranisBaseModel):
    _core_endpoint = "/config/organizations"
    _model_name = "organization"

    id: int | None = None
    name: str = ""
    description: str | None = ""
    address: Address = Field(default_factory=Address)


class Permission(TaranisBaseModel):
    _core_endpoint = "/config/permissions"
    _model_name = "permission"
    id: str | None = None
    name: str
    description: str = ""


class ACL(TaranisBaseModel):
    _core_endpoint = "/config/acls"
    _model_name = "acl"
    _pretty_name = "ACL"

    id: int | None = None
    name: str = ""
    description: str | None = ""
    item_type: ItemType | None = None
    item_id: str | None = None

    roles: list[int] = Field(default_factory=list)

    read_only: bool = True
    enabled: bool = True


class ParameterValue(TaranisBaseModel):
    _core_endpoint = "/config/parameter-values"
    _model_name = "parameter_value"
    id: int | None = None
    parameter: str = ""
    value: str | None = ""


class Worker(TaranisBaseModel):
    _core_endpoint = "/config/worker-types"
    _model_name = "worker_type"
    _pretty_name = "Worker Type"

    id: str | None = None
    name: str
    description: str | None = ""
    type: WORKER_TYPES
    category: WORKER_CATEGORY
    parameters: dict[str, str] = Field(default_factory=dict)


class Role(TaranisBaseModel):
    _core_endpoint = "/config/roles"
    _model_name = "role"
    _pretty_name = "Role"

    id: int | None = None
    name: str = ""
    description: str | None = ""
    permissions: list[str] = Field(default_factory=list)
    tlp_level: TLPLevel | None = None


class User(TaranisBaseModel):
    _core_endpoint = "/config/users"
    _model_name = "user"

    id: int | None = None
    name: str
    organization: dict | int
    permissions: list[str] | None = None
    profile: dict | None = None
    roles: list[int] | list[dict] = Field(default_factory=list)
    username: str = ""
    password: SecretStr | None = None

    @field_serializer("password", when_used="json")
    def dump_secret(self, v):
        if isinstance(v, SecretStr):
            return v.get_secret_value()
        return v


class TaranisConfig(TaranisBaseModel):
    default_collector_proxy: AnyUrl | Literal[""] = ""
    default_collector_interval: str = ""
    default_tlp_level: TLPLevel = TLPLevel.CLEAR
    default_story_conflict_retention: str = "200"
    default_news_item_conflict_retention: str = "200"


class Settings(TaranisBaseModel):
    _core_endpoint = "/admin/settings"
    _model_name = "settings"
    _pretty_name = "Settings"
    _cache_timeout = 30
    id: int = Field(default=1, frozen=True, exclude=True)
    settings: TaranisConfig = Field(default_factory=TaranisConfig)


class WordListEntry(TaranisBaseModel):
    value: str
    category: str | None = None
    description: str | None = None


class WordList(TaranisBaseModel):
    _core_endpoint = "/config/word-lists"
    _model_name = "word_list"
    _pretty_name = "Word List"

    id: int | None = None
    name: str
    description: str | None = ""
    usage: list[str] = Field(default_factory=list)
    link: str = ""
    entries: list[WordListEntry] | None = Field(default_factory=list)


class OSINTSource(TaranisBaseModel):
    _core_endpoint = "/config/osint-sources"
    _model_name = "osint_source"
    _pretty_name = "OSINT Source"

    id: str | None = None
    name: str
    description: str = ""
    rank: int = Field(default=0, ge=0, le=5)
    type: COLLECTOR_TYPES | None = None
    parameters: dict[str, str] | None = Field(default_factory=dict)

    icon: str | None = None
    enabled: bool | None = True
    status: TaskResult | None = None


class OSINTSourceUpdateModel(TaranisBaseModel):
    name: str | None = None
    description: str | None = None
    rank: int | None = Field(default=None, ge=0, le=5)
    parameters: dict[str, str] | None = None
    icon: str | None = None


class OSINTSourceGroup(TaranisBaseModel):
    _core_endpoint = "/config/osint-source-groups"
    _model_name = "osint_source_group"
    _pretty_name = "OSINT Source Group"

    id: str | None = None
    name: str
    description: str = ""
    default: bool = False

    osint_sources: list[str] = Field(default_factory=list)
    word_lists: list[int] = Field(default_factory=list)


class ProductParameterValue(TaranisBaseModel):
    TEMPLATE_PATH: str | None = None


class ProductType(TaranisBaseModel):
    _core_endpoint = "/config/product-types"
    _model_name = "product_type"
    _pretty_name = "Product Type"

    id: int | None = None
    title: str
    description: str = ""
    type: PRESENTER_TYPES
    parameters: ProductParameterValue = Field(default_factory=ProductParameterValue)
    report_types: list[int] = Field(default_factory=list)
    status: TaskResult | None = None


class PublisherPreset(TaranisBaseModel):
    _core_endpoint = "/config/publisher-presets"
    _model_name = "publisher_preset"
    _pretty_name = "Publisher Preset"

    id: str | None = None
    name: str
    type: PUBLISHER_TYPES
    description: str | None = ""
    parameters: dict[str, str] | None = Field(default_factory=dict)
    status: TaskResult | None = None


class ReportItemAttribute(TaranisBaseModel):
    id: int | None = None
    attribute: dict[str, str] | None = None
    attribute_id: int | None = None
    attribute_group_id: int | None = None
    title: str | None = None
    description: str | None = None
    index: int | None = None
    required: bool | None = None
    value: str | None = None
    type: str | None = None


class ReportItemAttributeGroup(TaranisBaseModel):
    id: int | None = None
    title: str | None = None
    description: str | None = None
    index: int | None = None
    attribute_group_items: list[ReportItemAttribute] = Field(default_factory=list)


class ReportItemType(TaranisBaseModel):
    _core_endpoint = "/config/report-item-types"
    _model_name = "report_item_type"
    _pretty_name = "Report Item Type"

    id: int | None = None
    title: str
    description: str = ""
    attribute_groups: list[ReportItemAttributeGroup] | None = Field(default_factory=list)


class Template(TaranisBaseModel):
    _core_endpoint = "/config/templates"
    _model_name = "template"
    _pretty_name = "Template"

    id: str
    content: str | None = None
    validation_status: dict | None = None


class AttributeEnum(TaranisBaseModel):
    id: int | None = None
    index: int | None = None
    value: str | None = None
    description: str | None = None
    imported: bool | None = None
    attribute_id: int | None = None


class Attribute(TaranisBaseModel):
    _core_endpoint = "/config/attributes"
    _model_name = "attribute"
    _pretty_name = "Attribute"

    id: int | None = None
    name: str
    description: str = ""
    type: AttributeType
    default_value: str = ""
    attribute_enums: list[AttributeEnum] = Field(default_factory=list)


class Bot(TaranisBaseModel):
    _core_endpoint = "/config/bots"
    _model_name = "bot"
    _pretty_name = "Bot"

    id: str | None = None
    name: str
    description: str = ""
    type: BOT_TYPES
    index: int | None = None
    enabled: bool = True
    parameters: dict[str, str] | None = Field(default_factory=dict)
    status: TaskResult | None = None


class Connector(TaranisBaseModel):
    _core_endpoint = "/config/connectors"
    _model_name = "connector"
    _pretty_name = "Connector"

    id: str | None = None
    name: str
    description: str = ""
    type: CONNECTOR_TYPES | None = Field(default=None)
    index: int | None = None
    parameters: dict[str, str] | None = Field(default_factory=dict)
    icon: str | None = None
    status: TaskResult | None = None


class WorkerParameterValue(TaranisBaseModel):
    name: str
    label: str | None = None
    parent: Literal["parameters"] = "parameters"
    type: str | None = None
    rules: list[str] = Field(default_factory=list)


class WorkerParameter(TaranisBaseModel):
    _core_endpoint = "/config/worker-parameters"
    _model_name = "worker_parameter"
    _pretty_name = "Worker Parameter"

    id: str
    parameters: list[WorkerParameterValue]



"""
This type stub file was generated by pyright.
"""

from datetime import datetime
from functools import cached_property
from typing import Literal

from pydantic import field_validator

from models.base import TaranisBaseModel

"""
This type stub file was generated by pyright.
"""

class NewsItem(TaranisBaseModel):
    _core_endpoint = ...
    osint_source_id: str
    hash: str | None = ...
    title: str | None = ...
    author: str | None = ...
    review: str | None = ...
    content: str | None = ...
    web_url: str | None = ...
    source: str | None = ...
    published: datetime | None = ...
    collected: datetime | None = ...
    attributes: list[str | dict] | None = ...
    language: str | None = ...
    @field_validator("language", mode="before")
    def normalize_language_code(cls, v): ...

class StoryTag(TaranisBaseModel):
    name: str
    size: int
    type: str | None = ...

class Story(TaranisBaseModel):
    _core_endpoint = ...
    _model_name = ...
    _pretty_name = ...
    _cache_timeout = ...
    id: str | None = ...
    title: str | None = ...
    description: str | None = ...
    created: datetime | None = ...
    updated: datetime | None = ...
    last_change: str | None = ...
    news_items: list[NewsItem] | None = ...
    links: list[str] | None = ...
    important: bool | None = ...
    read: bool | None = ...
    likes: int | None = ...
    dislikes: int | None = ...
    user_vote: Literal["like", "dislike", "", None] = ...
    summary: str | None = ...
    relevance: int | None = ...
    relevance_override: int | None = ...
    comments: str | None = ...
    in_reports_count: int | None = ...
    tags: list[dict] | None = ...
    attributes: list[dict] | None = ...
    @cached_property
    def search_field(self) -> str: ...

class AssessSource(TaranisBaseModel):
    id: str | None = ...
    icon: str | None = ...
    name: str
    type: str | None = ...

class FilterLists(TaranisBaseModel):
    _core_endpoint = ...
    _model_name = ...
    _pretty_name = ...
    tags: list[str] = ...
    sources: list[AssessSource] = ...
    groups: list[dict] = ...

class StoryUpdatePayload(TaranisBaseModel):
    vote: Literal["like", "dislike", ""] | None = ...
    important: bool | None = ...
    read: bool | None = ...
    title: str | None = ...
    description: str | None = ...
    comments: str | None = ...
    summary: str | None = ...
    tags: list[dict] | None = ...
    attributes: list[dict] | None = ...

class BulkAction(TaranisBaseModel):
    story_ids: list[str] = ...
    payload: StoryUpdatePayload | None = ...



from typing import Any

from pydantic import Field

from models.base import TaranisBaseModel


class ProfileSettingsDashboard(TaranisBaseModel):
    show_trending_clusters: bool = True
    show_charts: bool = True
    trending_cluster_days: int = 7
    trending_cluster_filter: list[Any] = Field(default_factory=list)


class ProfileSettings(TaranisBaseModel):
    _core_endpoint = "/users/profile"
    _model_name = "profile_settings"

    dark_theme: bool = False
    compact_view: bool = False
    show_charts: bool = False
    infinite_scroll: bool = True
    advanced_story_options: bool = False
    language: str = "en"
    hotkeys: dict[str, Any] = Field(default_factory=dict)
    split_view: bool = False
    end_of_shift: str | None = None
    highlight: bool = False
    dashboard: ProfileSettingsDashboard = Field(default_factory=ProfileSettingsDashboard)


class UserProfile(TaranisBaseModel):
    _core_endpoint = "/users"
    _model_name = "user_profile"

    id: int | None = None
    username: str = ""
    name: str
    organization: dict[str, Any] | None = None
    profile: ProfileSettings = Field(default_factory=ProfileSettings)
    permissions: list[str] | None = Field(default_factory=list)
    roles: list[dict[str, Any]] | None = Field(default_factory=list)



from models.admin import Job, Address, Organization, Role, User, Permission, ACL, Template, ReportItemType, ProductType
from models.types import TLPLevel, WORKER_TYPES, WORKER_CATEGORY
from models.base import TaranisBaseModel
from models.dashboard import Dashboard, TrendingCluster

__all__ = [
    "ACL",
    "Job",
    "Address",
    "Organization",
    "Role",
    "User",
    "Permission",
    "Dashboard",
    "Template",
    "ReportItemType",
    "ProductType",
    "TrendingCluster",
    "WORKER_TYPES",
    "WORKER_CATEGORY",
    "TaranisBaseModel",
    "TLPLevel",
]



"""
This type stub file was generated by pyright.
"""

from enum import IntEnum, StrEnum

"""
This type stub file was generated by pyright.
"""

class TLPLevel(StrEnum):
    CLEAR = ...
    GREEN = ...
    AMBER_STRICT = ...
    AMBER = ...
    RED = ...
    _ACCESSIBLE_NAMES = ...
    def get_accessible_levels(self) -> list[str]:
        """
        Return the list of TLPLevel members this level can access.
        """
        ...

    @classmethod
    def get_most_restrictive_tlp(cls, tlp_levels: list[TLPLevel]) -> TLPLevel:
        """
        Get the most restrictive TLP level from a list of TLP levels.
        If the list is empty, return the default TLP level (CLEAR).
        """
        ...

    @classmethod
    def get_tlp_level(cls, tlp_level: str) -> TLPLevel | None: ...

class ItemType(StrEnum):
    OSINT_SOURCE = ...
    OSINT_SOURCE_GROUP = ...
    WORD_LIST = ...
    REPORT_ITEM_TYPE = ...
    PRODUCT_TYPE = ...

class COLLECTOR_TYPES(StrEnum):
    RSS_COLLECTOR = ...
    EMAIL_COLLECTOR = ...
    TWITTER_COLLECTOR = ...
    SIMPLE_WEB_COLLECTOR = ...
    RT_COLLECTOR = ...
    MISP_COLLECTOR = ...
    MANUAL_COLLECTOR = ...
    PPN_COLLECTOR = ...

class BOT_TYPES(StrEnum):
    ANALYST_BOT = ...
    GROUPING_BOT = ...
    NLP_BOT = ...
    IOC_BOT = ...
    TAGGING_BOT = ...
    STORY_BOT = ...
    SUMMARY_BOT = ...
    WORDLIST_BOT = ...
    SENTIMENT_ANALYSIS_BOT = ...
    CYBERSEC_CLASSIFIER_BOT = ...

class PRESENTER_TYPES(StrEnum):
    PANDOC_PRESENTER = ...
    PDF_PRESENTER = ...
    HTML_PRESENTER = ...
    TEXT_PRESENTER = ...
    JSON_PRESENTER = ...
    STIX_PRESENTER = ...

class PUBLISHER_TYPES(StrEnum):
    FTP_PUBLISHER = ...
    SFTP_PUBLISHER = ...
    S3_PUBLISHER = ...
    EMAIL_PUBLISHER = ...
    WORDPRESS_PUBLISHER = ...
    MISP_PUBLISHER = ...
    TAXII_PUBLISHER = ...

class WORKER_TYPES(StrEnum):
    RSS_COLLECTOR = ...
    EMAIL_COLLECTOR = ...
    TWITTER_COLLECTOR = ...
    SIMPLE_WEB_COLLECTOR = ...
    MANUAL_COLLECTOR = ...
    RT_COLLECTOR = ...
    MISP_COLLECTOR = ...
    ANALYST_BOT = ...
    GROUPING_BOT = ...
    NLP_BOT = ...
    IOC_BOT = ...
    TAGGING_BOT = ...
    STORY_BOT = ...
    SUMMARY_BOT = ...
    SENTIMENT_ANALYSIS_BOT = ...
    CYBERSEC_CLASSIFIER_BOT = ...
    WORDLIST_BOT = ...
    PANDOC_PRESENTER = ...
    PDF_PRESENTER = ...
    HTML_PRESENTER = ...
    TEXT_PRESENTER = ...
    JSON_PRESENTER = ...
    STIX_PRESENTER = ...
    FTP_PUBLISHER = ...
    SFTP_PUBLISHER = ...
    S3_PUBLISHER = ...
    EMAIL_PUBLISHER = ...
    WORDPRESS_PUBLISHER = ...
    MISP_PUBLISHER = ...
    TAXII_PUBLISHER = ...
    MISP_CONNECTOR = ...
    PPN_COLLECTOR = ...

class CONNECTOR_TYPES(StrEnum):
    MISP_CONNECTOR = ...

class WORKER_CATEGORY(StrEnum):
    COLLECTOR = ...
    BOT = ...
    PRESENTER = ...
    PUBLISHER = ...
    CONNECTOR = ...

class WordListUsage(IntEnum):
    COLLECTOR_INCLUDELIST = ...
    COLLECTOR_EXCLUDELIST = ...
    TAGGING_BOT = ...

class OSINTState(IntEnum):
    DISABLED = ...
    UNKNOWN = ...
    OK = ...
    ERROR = ...
    NOT_MODIFIED = ...

class AttributeType(StrEnum):
    STRING = ...
    NUMBER = ...
    BOOLEAN = ...
    RADIO = ...
    ENUM = ...
    TEXT = ...
    RICH_TEXT = ...
    DATE = ...
    TIME = ...
    DATE_TIME = ...
    LINK = ...
    ATTACHMENT = ...
    TLP = ...
    CPE = ...
    CVE = ...
    CVSS = ...
    STORY = ...



"""
This type stub file was generated by pyright.
"""

from typing import ClassVar, TypeVar

from pydantic import BaseModel

"""
This type stub file was generated by pyright.
"""
T = TypeVar("T", bound="TaranisBaseModel")

class TaranisBaseModel(BaseModel):
    _core_endpoint: ClassVar[str]
    _cache_timeout: ClassVar[int]
    _model_name: ClassVar[str] = ...
    _pretty_name: ClassVar[str] = ...
    model_config = ...
    def model_dump(self, *args, **kwargs): ...
